import cnabssdk.clients

def get_organization(orgNameOrId):
    '''
    机构信息
    https://www.cn-abs.com/openapi.html#/detail/documents?id=16
    
    Args:
        orgNameOrId: 机构名称或者Id
    '''
    url = "organization/openapi/organizations/"+ orgNameOrId
    return cnabssdk.clients.cnabsclient().get(url, {})

def get_industries():
    '''
    行业列表
    https://www.cn-abs.com/openapi.html#/detail/documents?id=67
    
    Args:
        source: 行业类别，默认为证监会行业分类
    '''
    url = "organization/openapi/organizations/industry/证监会行业分类"
    return cnabssdk.clients.cnabsclient().get(url, {})

def get_organizations(keywords = "", industry = ""):
    '''
    机构列表
    https://www.cn-abs.com/openapi.html#/detail/documents?id=17
    
    Args:
        keywords: 查询关键字
        industry: 证监会行业
    '''
    url = "organization/openapi/organizations"
    params = {"keywords": keywords, "industry": industry }
    return cnabssdk.clients.cnabsclient().get(url, params)

def get_organization_ratings(orgNameOrId):
    '''
    机构评级
    https://www.cn-abs.com/openapi.html#/detail/documents?id=18
    
    Args:
        orgNameOrId: 机构名称或者Id
    '''
    url = "organization/openapi/organizations/"+ orgNameOrId +"/ratings"
    return cnabssdk.clients.cnabsclient().get(url, {})




import cnabssdk.clients


def get_statistic_by_exchanges(begin = "", end = "", statisticItem = "amount"):
    '''
    统计交易所、ABN市场的审批项目
    https://www.cn-abs.com/openapi.html#/detail/documents?id=39
    
    Args:
        begin: 开始时间
        end : 结束时间
        statisticItem: 按单数还是金额统计,number表示单数,amount表示金额
    '''
    url = "projects/openapi/projects/exchanges"
    params = {
        begin: begin,
        end: end,
        statisticItem: statisticItem
    }
    return cnabssdk.clients.cnabsclient().get(url, params)

def get_project_timelines(id):
    '''
    获取单个项目的审批周期
    https://www.cn-abs.com/openapi.html#/detail/documents?id=40
    
    Args:
        id: 产品id
    '''
    url = "projects/openapi/projects/"+ id +"/timelines"
    return cnabssdk.clients.cnabsclient().get(url, {})

def get_projects(keywords = "", begin = "", end = "", status= ""):
    '''
    获取交易所、ABN审批项目列表
    https://www.cn-abs.com/openapi.html#/detail/documents?id=41
    
    Args:
        keywords: keywords
        end: 结束时间
        begin: 开始时间
        status: 状态
    '''
    url = "projects/openapi/projects"
    params = {
        "keywords": keywords,
        "begin": begin,
        "end": end,
        "status": status
    }
    return cnabssdk.clients.cnabsclient().get(url, params)


import cnabssdk.common.utility

class base_entry(object):
    def __init__(self,id= '' ,code = '', name = ''):
        self.id = id
        self.code = code
        self.name = name

    def load_from_dict(self, obj):
        self.id = obj['id']
        self.code = obj['code']
        self.name = obj['name']

class deal_list_entry(base_entry):
    def __init__(self, id = "", name = "", code = "", status = "", shortname = ""):
        super().__init__(id, code, name)
        self.status = status
        self.short_name = shortname



import cnabssdk.clients
import time

def get_list(keywords="", begin="", end="", dealStatus="", year="", catalog="", orgName=""):
    '''
    证券列表 最大返回5000行数据
    https://www.cn-abs.com/openapi.html#/detail/documents?id=56
    Args:
        keywords: 关键字
        orgName: 机构名称
        catalog: 产品分类
        year: 年份
        dealStatus: 产品状态 支持中英文参数，选项如下（中文／英文）：过会中/Auditing 、发行中/Issueing 、存续期/Issued 、已清算/End 、停售/Stop 
        begin: 开始日期
        end: 结束日期
    '''
    url = "products/openapi/securities"
    params = {
        "keywords": keywords,
        "begin": begin,
        "end": end,
        "status": dealStatus,
        "year": year,
        "catalog": catalog,
        "orgName": orgName
    }
    return cnabssdk.clients.cnabsclient().get(url, params)

def get_detail(codeOrId):
    '''
    证券详情
    https://www.cn-abs.com/openapi.html#/detail/documents?id=57

    Args:
        codeOrId: 代码或者证券Id: 111111.SH
    Returns:
    '''
    url = "products/openapi/securities/" + codeOrId
    return cnabssdk.clients.cnabsclient().get(url, {})

def get_rating_snapshot(codeOrId, date = "", ratingAgency = ""):
    '''
    证券评级截面数据
    https://www.cn-abs.com/openapi.html#/detail/documents?id=58
    
    Args:
        codeOrId: 代码或者证券Id
        date: 日期
        ratingAgency: 评级机构
    '''
    url = "products/openapi/securities/"+ codeOrId +"/ratings/snapshot"
    params = {
        "date": date
    }
    return cnabssdk.clients.cnabsclient().get(url, params)

def get_ratings(codeOrId, begin = None, end = None, ratingAgency = None):
    '''
    证券评级历史
    https://www.cn-abs.com/openapi.html#/detail/documents?id=59
    
    Args:
        codeOrId: 代码或者证券Id
        begin: 开始时间
        end: 结束时间
        ratingAgency: 评级机构
    Returns:

    '''
    url = "products/openapi/securities/"+ codeOrId +"/ratings"
    params = {
        "begin": begin,
        "end": end,
        "ratingAgency": ratingAgency
    }
    return cnabssdk.clients.cnabsclient().get(url, params)

def get_payment_by_date(codeOrId, paymentDate):
    '''
    证券偿付明细
    https://www.cn-abs.com/openapi.html#/detail/documents?id=60
    
    Args:
        codeOrId: 代码或者证券Id
        paymentDate: 偿付日期
    '''
    url = "products/openapi/securities/"+ codeOrId +"/payments/"+ paymentDate
    params = {}
    return cnabssdk.clients.cnabsclient().get(url, params)

def get_payments(codeOrId):
    '''
    证券偿付历史
    https://www.cn-abs.com/openapi.html#/detail/documents?id=61
    
    Args:
        codeOrId: 代码或者证券Id
    '''
    url = "products/openapi/securities/"+ codeOrId +"/payments"
    return cnabssdk.clients.cnabsclient().get(url, {})

def get_snapshots(codeOrId, begin = "", end = ""):
    '''
    证券的动态截面的历史数据
    https://www.cn-abs.com/openapi.html#/detail/documents?id=62
    
    Args:
        codeOrId: 代码或者证券Id
        begin: 开始日期
        end: 结束日期
    '''
    url = "products/openapi/securities/"+ codeOrId +"/snapshots"
    params = {
        "begin": begin,
        "end": end
    }
    return cnabssdk.clients.cnabsclient().get(url, params)

def get_snapshot(codeOrId, date = ""):
    '''
    证券的最新截面数据
    https://www.cn-abs.com/openapi.html#/detail/documents?id=63
    
    Args:
        codeOrId: 代码或者证券Id
        date: 日期
    '''
    url = "products/openapi/securities/"+ codeOrId +"/snapshot"
    params = {
        "date": date
    }
    return cnabssdk.clients.cnabsclient().get(url, params)

def get_scheduled_payments(codeOrId):
    '''
    证券的固定摊还表
    https://www.cn-abs.com/openapi.html#/detail/documents?id=64
    
    Args:
        codeOrId: 代码或者证券Id

    '''
    url = "products/openapi/securities/"+ codeOrId +"/payments/scheduled"
    return cnabssdk.clients.cnabsclient().get(url, {})

def get_coupon(codeOrId):
    '''
    证券的发行利率信息
    https://www.cn-abs.com/openapi.html#/detail/documents?id=65
    
    Args:
        codeOrId: 代码或者证券Id
    '''
    url = "products/openapi/securities/"+ codeOrId +"/coupon"
    return cnabssdk.clients.cnabsclient().get(url, {})

def get_credits(codeOrId):
    '''
    证券增信
    https://www.cn-abs.com/openapi.html#/detail/documents?id=66
    
    Args:
        codeOrId: 代码或者证券Id    
    '''
    url = "products/openapi/securities/"+ codeOrId +"/credits"
    return cnabssdk.clients.cnabsclient().get(url, {})

def get_updated(requestTime = ""):
    '''
    获取证券更新历史
    https://www.cn-abs.com/openapi.html#/detail/documents?id=69
    
    Args: 
        requestTime: 更新时间（默认当天）
    '''
    if requestTime == "":
        requestTime = time.strftime("%Y-%m-%d", time.localtime)
    url = "products/openapi/securities/updated/"+ requestTime
    params= {}
    return cnabssdk.clients.cnabsclient().get(url, params)


import cnabssdk.clients

def get_list(keywords = "", status = "", year = "", catalog = "", orgname = ""):
    '''
    获得产品列表信息
    https://www.cn-abs.com/openapi.html#/detail/documents?id=45
    
    Args:
        keywords: 关键字
        status:  产品状态，支持中英文参数，选项如下（中文／英文）：过会中/Auditing 、发行中/Issueing 、存续期/Issued 、已清算/End 、停售/Stop 
        year: 年份
        catalog: 产品分类
        orgName: 机构名称
    '''
    url = "products/openapi/deals"
    params = {
        "keywords": keywords,
        "status": status,
        "year": year,
        "catalog": catalog,
        "orgname": orgname
        }
    return cnabssdk.clients.cnabsclient().get(url, params)

def get_detail(dealIdOrName):
    '''
    产品详情
    https://www.cn-abs.com/openapi.html#/detail/documents?id=46
    
    Args:
        nameOrId: 产品全称或者Id
    '''
    url = "products/openapi/deals/" + dealIdOrName
    return cnabssdk.clients.cnabsclient().get(url, {})

def get_dates(nameOrId, dateType = ""):
    '''
    产品相关日期
    https://www.cn-abs.com/openapi.html#/detail/documents?id=47
    
    Args:
        nameOrId: 产品全称或者Id
        dateType: 时间类型（默认为空）
    '''
    url = "products/openapi/deals/"+ nameOrId +"/dates"
    params = {"dateType": dateType }
    return cnabssdk.clients.cnabsclient().get(url, params)

def get_payments_dates(nameOrId):
    '''
    产品的偿付列表
    https://www.cn-abs.com/openapi.html#/detail/documents?id=48
    
    Args:
        nameOrId: 产品全称或者Id
    '''
    url = "products/openapi/deals/"+ nameOrId +"/payments/schedule"
    return  cnabssdk.clients.cnabsclient().get(url, {})

def get_deal_orgs(nameOrId):
    '''
    产品的相关机构信息
    https://www.cn-abs.com/openapi.html#/detail/documents?id=49
    
    Args:
        nameOrId: 产品全称或者Id
    '''
    url = "products/openapi/deals/"+ nameOrId +"/orgs"
    return  cnabssdk.clients.cnabsclient().get(url, {})
 
def get_deal_orgs_by_role(nameOrId, role = ""):
    '''
    通过角色获得参与机构信息
    https://www.cn-abs.com/openapi.html#/detail/documents?id=50
    
    Args:
        nameOrId: 产品全称或者Id
        role: 机构角色
    '''
    url = "products/openapi/deals/"+ nameOrId +"/orgs/"+ role
    params = {"role": role }
    return  cnabssdk.clients.cnabsclient().get(url, params)

def get_executions(nameOrId):
    '''
    产品承销信息
    https://www.cn-abs.com/openapi.html#/detail/documents?id=51
    
    Args:
        nameOrId: 产品全称或者Id
    '''
    url = "products/openapi/deals/"+ nameOrId +"/orgs/execution"
    return cnabssdk.clients.cnabsclient().get(url, {})

def get_snapshot(nameOrId, date = ""):
    '''
    产品动态信息
    https://www.cn-abs.com/openapi.html#/detail/documents?id=52
    
    Args:
        nameOrId: 产品全称或者Id
        date：日期 
    '''
    url = "products/openapi/deals/"+ nameOrId +"/snapshot"
    params = {"date": date }
    return cnabssdk.clients.cnabsclient().get(url, params)

def get_snapshots(nameOrId, begin = None, end = None):
    '''
    产品动态信息历史
    https://www.cn-abs.com/openapi.html#/detail/documents?id=53
    
    Args:
        nameOrId: 产品全称或者Id
        begin: 开始时间
        end: 结束时间
    '''
    url = "products/openapi/deals/"+ nameOrId +"/snapshots"
    params = {"begin": begin , "end": end }
    return cnabssdk.clients.cnabsclient().get(url, params)

def get_securities(nameOrId):
    '''
    产品证券简略信息
    https://www.cn-abs.com/openapi.html#/detail/documents?id=54
    
    Args:
        nameOrId: 产品全称或者Id
    '''
    url = "products/openapi/deals/"+ nameOrId +"/securities"
    return cnabssdk.clients.cnabsclient().get(url, {})

def get_feePayment(nameOrId, paymentDate = ""):
    '''
    产品费用偿付
    https://www.cn-abs.com/openapi.html#/detail/documents?id=55
    
    Args:
        nameOrId: 产品全称或者Id
        paymentDate: 支付日
    '''
    url = "products/openapi/deals/"+ nameOrId +"/feePayment"
    params = {"paymentDate": paymentDate}
    return cnabssdk.clients.cnabsclient().get(url, params)

def get_categories():
    '''
    产品类别列表
    https://www.cn-abs.com/openapi.html#/detail/documents?id=68
    
    Args:
        source: 产品类别的分类
    '''
    url = "products/openapi/deals/category/" 
    params = {}
    return cnabssdk.clients.cnabsclient().get(url, params)








import cnabssdk.clients


def get_distribution_names(dealNameOrId):
    '''
    资产分布的名称
    参考文档: https://www.cn-abs.com/openapi.html#/detail/documents?id=8

    Args:
        dealNameOrId: 产品全称或者ID
    
    Returns: Array
        code: 代码
        name: 名称
        short_name:  简称
    '''
    url = "assets/openapi/assets/"+ dealNameOrId +"/distributions"
    return cnabssdk.clients.cnabsclient().get(url, {})


def get_distributions(dealNameOrId, distribute_name = "", date = ""):
    '''
    资产分布的明细数据
    https://www.cn-abs.com/openapi.html#/detail/documents?id=9
    
    Args:
        dealNameOrId: 产品全称或者Id 
        date: 产品偿付日期
        name: 分布类别
    '''
    url = "assets/openapi/assets/"+ dealNameOrId +"/distributions/"+ distribute_name +"/"+ date
    params = {}
    return cnabssdk.clients.cnabsclient().get(url, params)


def get_deliquencies(dealNameOrId, date = ""):
    '''
    获得产品的逾期数据
    https://www.cn-abs.com/openapi.html#/detail/documents?id=10
    
    Args:
        dealNameOrId: 产品全称或者Id 
        date: 日期
    '''
    url = "assets/openapi/assets/"+ dealNameOrId +"/distributions/overdue/"+ date
    params = {}
    return cnabssdk.clients.cnabsclient().get(url, params)

def get_defaulted_process(dealNameOrId, date = ""):
    '''
    获得产品的违约处置数据
    https://www.cn-abs.com/openapi.html#/detail/documents?id=11
    
    Args:
        dealNameOrId: 产品全称或者Id 
        date: 日期
    Returns:
        
    '''
    url = "assets/openapi/assets/"+ dealNameOrId +"/distributions/default_process/"+ date
    params = {}
    return cnabssdk.clients.cnabsclient().get(url, params)


def get_promised_cashflows (dealNameOrId, date = ""):
    '''
    获得该期报告的预测归集现金流
    https://www.cn-abs.com/openapi.html#/detail/documents?id=12
    
    Args:
        dealNameOrId: 产品全称或者Id 
        date: 日期
    Returns:
        
    '''
    url = "assets/openapi/assets/"+ dealNameOrId +"/cashflows/forecast/report/"+ date
    params = {}
    return cnabssdk.clients.cnabsclient().get(url, params)

def get_repayment(dealNameOrId, date = ""):
    '''
    获得该期偿付报告的资产归集现金流
    https://www.cn-abs.com/openapi.html#/detail/documents?id=13
    
    Args:
        dealNameOrId: 产品全称或者Id 
        date: 日期
    '''
    url = "assets/openapi/assets/"+ dealNameOrId +"/cashflows/"+ date
    params = {"date": date}
    return cnabssdk.clients.cnabsclient().get(url, params)

def get_dates(dealNameOrId):
    '''
    获得该产品的资产偿付时间序列
    https://www.cn-abs.com/openapi.html#/detail/documents?id=14
    
    Args:
        dealNameOrId: 产品全称或者Id
    '''
    url = "assets/openapi/assets/"+ dealNameOrId +"/dates"
    dates = cnabssdk.clients.cnabsclient().get(url, {})
    result = []
    for item in dates:
        result.append(item.date)
    return result


def get_statistics(dealNameOrId, date, itemName = ""):
    '''
    获得该产品的该期的资产特征数据
    https://www.cn-abs.com/openapi.html#/detail/documents?id=15
    
    Args:
        dealNameOrId: 产品全称或者Id 
        itemName: 指标名称(为空返回全部指标)
        date: 日期（yyyy-MM-dd）
    '''
    url = "assets/openapi/assets/"+ dealNameOrId +"/statistics"
    params = {"itemName": itemName, "date": date}
    return cnabssdk.clients.cnabsclient().get(url, params)


